# Changelog

## 0.1.0-alpha.1 (2025-08-27)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/dataleonlabs/dataleon-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([ec2a77c](https://github.com/dataleonlabs/dataleon-python/commit/ec2a77c58ca2f109464ae026f527aaba5b7dbed2))
* **api:** api update ([7ded36e](https://github.com/dataleonlabs/dataleon-python/commit/7ded36ec68b2b2c522ea546049903242642a3c83))
* **api:** api update ([0b0f975](https://github.com/dataleonlabs/dataleon-python/commit/0b0f975bd9db1c7b41bf2654f3bb07ad97376b25))
* **api:** api update ([b865d6b](https://github.com/dataleonlabs/dataleon-python/commit/b865d6b5d9771883b2f5cd5c2fdd9d406b345c8b))
* **api:** api update ([60e3cfa](https://github.com/dataleonlabs/dataleon-python/commit/60e3cfa6959dd5997caba9da5b20701a6b17ce1c))
* **api:** api update ([1a991a6](https://github.com/dataleonlabs/dataleon-python/commit/1a991a605afaecea9533408e3719a98f0c860bbf))
* **api:** api update ([9752cda](https://github.com/dataleonlabs/dataleon-python/commit/9752cda974ff7534c225a0b3c6abaf5abf26664f))
* **api:** api update ([817c5a9](https://github.com/dataleonlabs/dataleon-python/commit/817c5a9a62e8d5596413fbb63332c05ac6a94e36))
* **api:** api update ([0d7cfa1](https://github.com/dataleonlabs/dataleon-python/commit/0d7cfa1f9bf9f4ff95ab4b34d981682bd5c53f68))
* **api:** api update ([b712b46](https://github.com/dataleonlabs/dataleon-python/commit/b712b460b45af0344f8e678620955aab24ae4b1e))
* **api:** api update ([682aa0d](https://github.com/dataleonlabs/dataleon-python/commit/682aa0d71c263dff0a05f99ad643036fdb8c3a2f))
* **api:** manual updates ([4eb679e](https://github.com/dataleonlabs/dataleon-python/commit/4eb679e80eda3416cdbc7f000580bf69f696d224))
* **api:** manual updates ([de826b6](https://github.com/dataleonlabs/dataleon-python/commit/de826b69b93cc0776c8032a9490bef99d073125f))
* **api:** manual updates ([a72956b](https://github.com/dataleonlabs/dataleon-python/commit/a72956bde35f40058e261b24b2c635f3d5a31864))
* **api:** manual updates ([c5ff92d](https://github.com/dataleonlabs/dataleon-python/commit/c5ff92d36e000542bf41b0b1f4c07727f43f0d71))
* **api:** update via SDK Studio ([b5194b9](https://github.com/dataleonlabs/dataleon-python/commit/b5194b93e2deffef6734e6917a82fd1fcc45b1c7))
* **api:** update via SDK Studio ([a300449](https://github.com/dataleonlabs/dataleon-python/commit/a300449dfbf14cd2bd659eba4dd05cd84797522b))
* **api:** update via SDK Studio ([889a514](https://github.com/dataleonlabs/dataleon-python/commit/889a5144f675cae403f426fc894934e464dcb2a9))
* **api:** update via SDK Studio ([2bad5fe](https://github.com/dataleonlabs/dataleon-python/commit/2bad5fe5a06cd13e36685633593f6637437dd0f9))
* **api:** update via SDK Studio ([8530726](https://github.com/dataleonlabs/dataleon-python/commit/85307267a962d22fdecef8395523d4e5a8930f1a))
* **api:** update via SDK Studio ([77c6b67](https://github.com/dataleonlabs/dataleon-python/commit/77c6b679d5b9fedcc443b8030908e24cdef07c49))
* **api:** update via SDK Studio ([a61e1cc](https://github.com/dataleonlabs/dataleon-python/commit/a61e1cc00d6f9bdf466fb4eef1f5858faffd46f6))
* **api:** update via SDK Studio ([83a224d](https://github.com/dataleonlabs/dataleon-python/commit/83a224dafe5bc09eabdd8eac71f8b819667b116d))
* **api:** update via SDK Studio ([aa6d764](https://github.com/dataleonlabs/dataleon-python/commit/aa6d764aa50a0153168c6904962ec5ee2679d736))


### Bug Fixes

* avoid newer type syntax ([2535c11](https://github.com/dataleonlabs/dataleon-python/commit/2535c117430d3679577f469e1352edfd6f573600))


### Chores

* **internal:** change ci workflow machines ([d67b2d3](https://github.com/dataleonlabs/dataleon-python/commit/d67b2d3b7ee3fee369eb6c1fd3862fd88af0d55c))
* **internal:** codegen related update ([f146cbf](https://github.com/dataleonlabs/dataleon-python/commit/f146cbf3c177b2b5d103fb5fae7226e9f7b117d1))
* **internal:** update comment in script ([e720cfd](https://github.com/dataleonlabs/dataleon-python/commit/e720cfdd3e15e2db39c6ed410e554a40d41072aa))
* **internal:** update pyright exclude list ([a5a6c90](https://github.com/dataleonlabs/dataleon-python/commit/a5a6c90735519474c5cb6371bccfab1f631c2577))
* update @stainless-api/prism-cli to v5.15.0 ([24c0124](https://github.com/dataleonlabs/dataleon-python/commit/24c0124e940eb14511a84a2ffed47d92a74b313c))
* update github action ([c6f64fd](https://github.com/dataleonlabs/dataleon-python/commit/c6f64fdf9404988f70e81a481905b1bc8ed9bf51))
* update SDK settings ([0aefed1](https://github.com/dataleonlabs/dataleon-python/commit/0aefed135a6291bf3989ae7119ce427f2bcf1f77))
* update SDK settings ([9d19ee4](https://github.com/dataleonlabs/dataleon-python/commit/9d19ee49d23a9c2f010d095ae88c3d97af8a9066))
